@@ -13,14 +13,18 @@
 ##############################################################################
 """Interfaces for session utility.
 """
-from zope.interface import Interface
-from zope.interface.common.mapping import IMapping, IReadMapping, IWriteMapping
-from zope import schema
 from zope.i18nmessageid import ZopeMessageFactory as _
+from zope.interface import Interface
+from zope.interface.common.mapping import IMapping
+from zope.interface.common.mapping import IReadMapping
+from zope.interface.common.mapping import IWriteMapping
+
+from zope import schema
 
 
 __docformat__ = 'restructuredtext'
 
+
 class IClientIdManager(Interface):
     """
     Manages client identifiers.
@@ -82,7 +86,7 @@ class ISessionDataContainer(IReadMapping, IWriteMapping):
             "out later than the 'Data object timeout value' by  a factor "
             "of (at most) this many seconds."
         ),
-        default=10*60,
+        default=10 * 60,
         required=True,
         min=0,
     )
